package l2vote;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.lang.reflect.Type;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.List;

public class ApiClient {
    public List<Vote> fetchVotes() throws Exception {
        // Установим поддержку TLS 1.2 для Java 8
        System.setProperty("https.protocols", "TLSv1.2");

        // Формируем URL
        String url = String.format(Config.API_URL_TEMPLATE, Config.SERVER_ID);
       // System.out.println("Request URL: " + url); // Отладочный вывод

        HttpURLConnection conn = (HttpURLConnection) new URL(url).openConnection();
        conn.setRequestMethod("GET");

        // Добавляем заголовки
        conn.setRequestProperty("X-API-KEY", Config.API_KEY);
        conn.setRequestProperty("User-Agent", "Mozilla/5.0 (compatible; Java API Client)");

        // Проверяем код ответа
        if (conn.getResponseCode() != 200) {
            throw new RuntimeException("API error: HTTP " + conn.getResponseCode());
        }

        // Читаем ответ
        BufferedReader reader = new BufferedReader(new InputStreamReader(conn.getInputStream()));
        StringBuilder response = new StringBuilder();
        String line;
        while ((line = reader.readLine()) != null) {
            response.append(line);
        }
        reader.close();

        // Логируем весь ответ для понимания структуры
        // System.out.println("API Response: " + response.toString());

        // Используем Gson для парсинга JSON в список объектов Vote
        Gson gson = new Gson();
        Type listType = new TypeToken<List<Vote>>() {}.getType();
        return gson.fromJson(response.toString(), listType);  // Преобразуем в список объектов Vote
    }
}
