package l2vote;

import java.io.IOException;
import java.nio.file.Paths;
import java.util.logging.*;

public class LogManagerVote {

    private static LogManagerVote instance; // Экземпляр Singleton
    private Logger logger;

    // Закрытый конструктор, чтобы никто не мог создать объект напрямую
    private LogManagerVote() {
        try {
            // Получаем абсолютный путь к текущей директории
            String logFilePath = Paths.get("").toAbsolutePath().toString() + "/votes.log";

            // Создаем логгер
            logger = Logger.getLogger(LogManagerVote.class.getName());

            // Очищаем существующие обработчики (чтобы избежать вывода в консоль)
            Handler[] handlers = logger.getHandlers();
            for (Handler handler : handlers) {
                logger.removeHandler(handler);
            }

            // Устанавливаем FileHandler для записи логов в файл
            FileHandler fileHandler = new FileHandler(logFilePath, true); // append = true для добавления в конец файла
            fileHandler.setFormatter(new SimpleFormatter());  // Устанавливаем простой формат вывода

            // Добавляем обработчик в логгер
            logger.addHandler(fileHandler);
            logger.setLevel(Level.INFO);  // Устанавливаем уровень логирования

        } catch (IOException e) {
            System.err.println("Ошибка при настройке логгера: " + e.getMessage());
        }
    }

    // Метод для получения единственного экземпляра LogManager
    public static synchronized LogManagerVote getInstance() {
        if (instance == null) {
            instance = new LogManagerVote(); // Создаем экземпляр, если он еще не был создан
        }
        return instance;
    }

    // Метод для записи информационного лога
    public void info(String message) {
        logger.info(message);
    }

    // Метод для записи ошибки
    public void error(String message) {
        logger.severe(message);
    }

    // Метод для записи предупреждения
    public void warning(String message) {
        logger.warning(message);
    }

    // Метод для записи общего лога
    public void log(Level level, String message) {
        logger.log(level, message);
    }
}
