package l2vote;

import l2.gameserver.ThreadPoolManager;
import l2.gameserver.dao.CharacterDAO;
import l2.gameserver.database.DatabaseFactory;
import l2.gameserver.scripts.ScriptFile;
import l2.gameserver.taskmanager.DelayedItemsManager;
import l2vote.ApiClient;
import l2vote.DatabaseManager;

import java.sql.Connection;
import java.sql.SQLException;
import java.text.SimpleDateFormat;
import java.util.*;

import java.util.Date;
import java.util.List;
import java.util.logging.LogManager;

import static l2vote.Config.*;

public class VoteProcessor implements ScriptFile {

    private String today;

    public VoteProcessor() {
        // Инициализация текущей даты
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        this.today = sdf.format(new Date());
    }

    public void start() {
        try (Connection connection = DatabaseFactory.getInstance().getConnection();
             DatabaseManager dbManager = new DatabaseManager(connection)) {

            // Создаем таблицу
            dbManager.createTableIfNotExists();

            // Получаем данные из API
            ApiClient apiClient = new ApiClient();
            // System.out.println("Получение новых голосов...");
            List<Vote> votes = apiClient.fetchVotes();

            // Обрабатываем каждый голос
            for (Vote vote : votes) {
                if (dbManager.addVote(vote.getCharName(),vote.getVoteTime(),vote.getId())) {
                    // System.out.println("Добавлен новый голос: " + vote);

                    LogManagerVote.getInstance().info("Добавлен новый голос: " + vote);
                }
            }


            // Выдаем награды
            dbManager.giveRewards(ALLOW_MULTIPLE_REWARDS);

        } catch (Exception e) {
            e.printStackTrace();
        }
    }



    @Override
    public void onLoad() {
        // Периодическое выполнение задачи с интервалом
        Config.loadAISettings();
        ThreadPoolManager.getInstance().scheduleAtFixedRate(this::start, 5000, POLLING_DELAY_MINUTES);
    }

    @Override
    public void onReload() {

    }

    @Override
    public void onShutdown() {

    }
}

